import json

def serverless(function):
    def wrapper(req, context) -> object:
        try:
            response = function(req)
            statusCode, body = response.values()

            return {
                "statusCode": statusCode,
                "body": json.dumps(body),
                "headers": {
                    "Content-Type": "application/json"
                }
            }
        except Exception as e:
            return {
                "statusCode": 500,
                "body": json.dumps({'error': True, 'message': str(e)}),
                "headers": {
                    "Content-Type": "application/json"
                }
            }

    return wrapper



import setuptools

with open('README.md', 'r') as fh:
    long_description = fh.read()

setuptools.setup(
    name="serverless.py",
    version="0.0.3",
    author="Matheus Vinícius",
    author_email="mtwzim@gmail.com",
    description="A Simple Decorator to create a REST Python API in serverless",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/mtwzim/python-serverless",
    packages=[
        'serverless',
    ],
    classifiers=[
        "Programming Language :: Python :: 3.7",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent"
    ],
    python_required=">=3.7.9"
);
